@@ -16,12 +16,14 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #ifndef PASTEDIALOG_H
 #define PASTEDIALOG_H
 
-#include <KDialog>
+#include <QDialog>
+#include <KSharedConfig>
 #include "ui_pastedlgbase.h"
 
 
@@ -33,25 +35,25 @@ namespace kt
      * @author Ivan Vasic
      * @brief Torrent URL paste dialog
      **/
-    class PasteDialog: public KDialog, public Ui_PasteDlgBase
+    class PasteDialog: public QDialog, public Ui_PasteDlgBase
     {
         Q_OBJECT
     public:
-        PasteDialog(Core* core, QWidget* parent = 0, Qt::WFlags fl = 0);
-        virtual ~PasteDialog();
+        PasteDialog(Core* core, QWidget* parent = 0, Qt::WindowFlags fl = 0);
+        ~PasteDialog();
 
         /**
         * Load the state of the dialog
         */
-        void loadState(KSharedConfigPtr cfg);
+        void loadState(KSharedConfig::Ptr cfg);
 
         /**
         * Save the state of the dialog
         */
-        void saveState(KSharedConfigPtr cfg);
+        void saveState(KSharedConfig::Ptr cfg);
 
     public slots:
-        virtual void accept();
+        void accept() override;
 
     private:
         void loadGroups();
