@@ -17,11 +17,13 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #ifndef KTGROUP_H
 #define KTGROUP_H
 
-#include <qstring.h>
-#include <qicon.h>
+#include <QIcon>
+#include <QString>
+
 #include <ktcore_export.h>
 #include <util/constants.h>
 
