@@ -22,9 +22,10 @@
 #define ACTIVITY_H
 
 #include <QWidget>
-#include <ksharedconfig.h>
+#include <KSharedConfig>
+#include <KParts/Part>
+
 #include <ktcore_export.h>
-#include <kparts/part.h>
 
 class QMenu;
 
@@ -40,7 +41,7 @@ namespace kt
         Q_OBJECT
     public:
         ActivityPart(Activity* parent);
-        virtual ~ActivityPart();
+        ~ActivityPart();
 
         /// Set the XML GUI file of the part
         void setXMLGUIFile(const QString& xml_gui);
@@ -57,7 +58,7 @@ namespace kt
         Q_OBJECT
     public:
         Activity(const QString& name, const QString& icon, int weight, QWidget* parent);
-        virtual ~Activity();
+        ~Activity();
 
         /// Get the name of the activity
         const QString& name() const {return activity_name;}
