@@ -18,11 +18,14 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
+
 #include "queuemanager.h"
 
 #include <QNetworkConfigurationManager>
-#include <kmessagebox.h>
-#include <klocalizedstring.h>
+
+#include <KLocalizedString>
+#include <KMessageBox>
+
 #include <util/log.h>
 #include <util/error.h>
 #include <util/sha1hash.h>
@@ -36,6 +39,7 @@
 #include <interfaces/torrentinterface.h>
 #include <interfaces/trackerslist.h>
 #include <settings.h>
+#include <algorithm>
 #include <climits>
 
 
@@ -67,9 +71,9 @@ namespace kt
     void QueueManager::append(bt::TorrentInterface* tc)
     {
         downloads.append(tc);
-        connect(tc, SIGNAL(diskSpaceLow(bt::TorrentInterface*, bool)), this, SLOT(onLowDiskSpace(bt::TorrentInterface*, bool)));
-        connect(tc, SIGNAL(torrentStopped(bt::TorrentInterface*)), this, SLOT(torrentStopped(bt::TorrentInterface*)));
-        connect(tc, SIGNAL(updateQueue()), this, SLOT(orderQueue()));
+        connect(tc, &TorrentInterface::diskSpaceLow, this, &QueueManager::onLowDiskSpace);
+        connect(tc, &TorrentInterface::torrentStopped, this, &QueueManager::torrentStopped);
+        connect(tc, &TorrentInterface::updateQueue, this, &QueueManager::orderQueue);
     }
 
     void QueueManager::remove(bt::TorrentInterface* tc)
@@ -210,7 +214,7 @@ namespace kt
     void QueueManager::stop(QList<bt::TorrentInterface*> & todo)
     {
         ordering = true;
-        foreach (bt::TorrentInterface* tc, todo)
+        for (bt::TorrentInterface* tc : qAsConst(todo))
         {
             stop(tc);
         }
@@ -226,7 +230,7 @@ namespace kt
         {
             QStringList names;
             QList<bt::TorrentInterface*> tmp;
-            foreach (bt::TorrentInterface* tc, todo)
+            for (bt::TorrentInterface* tc : qAsConst(todo))
             {
                 const TorrentStats& s = tc->getStats();
                 if (!s.completed && !tc->checkDiskSpace(false))
@@ -240,7 +244,7 @@ namespace kt
             {
                 if (KMessageBox::questionYesNoList(0, i18n("Not enough disk space for the following torrents. Do you want to start them anyway?"), names) == KMessageBox::No)
                 {
-                    foreach (bt::TorrentInterface* tc, tmp)
+                    for (bt::TorrentInterface* tc : qAsConst(tmp))
                         todo.removeAll(tc);
                 }
             }
@@ -265,7 +269,7 @@ namespace kt
     {
         QStringList names;
         QList<bt::TorrentInterface*> tmp;
-        foreach (bt::TorrentInterface* tc, todo)
+        for (bt::TorrentInterface* tc : qAsConst(todo))
         {
             const TorrentStats& s = tc->getStats();
             if (s.completed && tc->overMaxSeedTime())
@@ -279,12 +283,12 @@ namespace kt
         {
             if (KMessageBox::questionYesNoList(0, i18n("The following torrents have reached their maximum seed time. Do you want to start them anyway?"), names) == KMessageBox::No)
             {
-                foreach (bt::TorrentInterface* tc, tmp)
+                for (bt::TorrentInterface* tc : qAsConst(tmp))
                     todo.removeAll(tc);
             }
             else
             {
-                foreach (bt::TorrentInterface* tc, tmp)
+                for (bt::TorrentInterface* tc : qAsConst(tmp))
                     tc->setMaxSeedTime(0.0f);
             }
         }
@@ -294,7 +298,7 @@ namespace kt
     {
         QStringList names;
         QList<bt::TorrentInterface*> tmp;
-        foreach (bt::TorrentInterface* tc, todo)
+        for (bt::TorrentInterface* tc : qAsConst(todo))
         {
             const TorrentStats& s = tc->getStats();
             if (s.completed && tc->overMaxRatio())
@@ -308,12 +312,12 @@ namespace kt
         {
             if (KMessageBox::questionYesNoList(0, i18n("The following torrents have reached their maximum share ratio. Do you want to start them anyway?"), names) == KMessageBox::No)
             {
-                foreach (bt::TorrentInterface* tc, tmp)
+                for (bt::TorrentInterface* tc : qAsConst(tmp))
                     todo.removeAll(tc);
             }
             else
             {
-                foreach (bt::TorrentInterface* tc, tmp)
+                for (bt::TorrentInterface* tc : qAsConst(tmp))
                     tc->setMaxShareRatio(0.0f);
             }
         }
@@ -324,7 +328,7 @@ namespace kt
         if (todo.count() == 0)
             return;
 
-        // check dispace stuff
+        // check diskspace stuff
         checkDiskSpace(todo);
         if (todo.count() == 0)
             return;
@@ -338,7 +342,7 @@ namespace kt
             return;
 
         // start what is left
-        foreach (bt::TorrentInterface* tc, todo)
+        for (bt::TorrentInterface* tc : qAsConst(todo))
         {
             const TorrentStats& s = tc->getStats();
             if (s.running)
@@ -361,7 +365,7 @@ namespace kt
     {
         if (enabled())
         {
-            foreach (bt::TorrentInterface* tc, downloads)
+            for (bt::TorrentInterface* tc : qAsConst(downloads))
                 tc->setAllowedToStart(true);
 
             orderQueue();
@@ -370,7 +374,7 @@ namespace kt
         {
             // first get the list of torrents which need to be started
             QList<bt::TorrentInterface*> todo;
-            foreach (bt::TorrentInterface* tc, downloads)
+            for (bt::TorrentInterface* tc : qAsConst(downloads))
             {
                 const TorrentStats& s = tc->getStats();
                 if (s.running)
@@ -399,7 +403,7 @@ namespace kt
 
         // first get the list of torrents which need to be started
         QList<bt::TorrentInterface*> todo;
-        foreach (bt::TorrentInterface* tc, downloads)
+        for (bt::TorrentInterface* tc : qAsConst(downloads))
         {
             const TorrentStats& s = tc->getStats();
             if (s.running || tc->getJobQueue()->runningJobs() || !s.autostart)
@@ -520,7 +524,7 @@ namespace kt
 
     bool QueueManager::alreadyLoaded(const bt::SHA1Hash& ih) const
     {
-        foreach (const bt::TorrentInterface* tor, downloads)
+        for (const bt::TorrentInterface* tor : qAsConst(downloads))
         {
             if (tor->getInfoHash() == ih)
                 return true;
@@ -530,7 +534,7 @@ namespace kt
 
     void QueueManager::mergeAnnounceList(const bt::SHA1Hash& ih, const TrackerTier* trk)
     {
-        foreach (bt::TorrentInterface* tor, downloads)
+        for (bt::TorrentInterface* tor : qAsConst(downloads))
         {
             if (tor->getInfoHash() == ih)
             {
@@ -560,7 +564,7 @@ namespace kt
         QueuePtrList download_queue;
         QueuePtrList seed_queue;
 
-        foreach (TorrentInterface* tc, downloads)
+        for (TorrentInterface* tc : qAsConst(downloads))
         {
             const TorrentStats& s = tc->getStats();
             if (s.running || (tc->isAllowedToStart() && !s.stopped_by_error && !tc->getJobQueue()->runningJobs()))
@@ -576,7 +580,7 @@ namespace kt
         }
 
         int num_running = 0;
-        foreach (bt::TorrentInterface* tc, download_queue)
+        for (bt::TorrentInterface* tc : qAsConst(download_queue))
         {
             const TorrentStats& s = tc->getStats();
 
@@ -603,7 +607,7 @@ namespace kt
         }
 
         num_running = 0;
-        foreach (bt::TorrentInterface* tc, seed_queue)
+        for (bt::TorrentInterface* tc : qAsConst(seed_queue))
         {
             const TorrentStats& s = tc->getStats();
             if (num_running < max_seeds || max_seeds == 0)
@@ -650,7 +654,7 @@ namespace kt
         {
             // new torrents have the lowest priority
             // so everybody else gets a higher priority
-            foreach (TorrentInterface* otc, downloads)
+            for (TorrentInterface* otc : qAsConst(downloads))
             {
                 int p = otc->getPriority();
                 otc->setPriority(p + 1);
@@ -676,7 +680,7 @@ namespace kt
 
     void QueueManager::torrentsRemoved(QList<bt::TorrentInterface*>& tors)
     {
-        foreach (bt::TorrentInterface* tc, tors)
+        for (bt::TorrentInterface* tc : qAsConst(tors))
             remove(tc);
         rearrangeQueue();
         orderQueue();
@@ -705,7 +709,7 @@ namespace kt
         }
         else
         {
-            foreach (TorrentInterface* tc, downloads)
+            for (TorrentInterface* tc : qAsConst(downloads))
             {
                 const TorrentStats& s = tc->getStats();
                 if (s.running)
@@ -782,7 +786,7 @@ namespace kt
         bool can_decrease = false;
 
         // find all stalled ones
-        foreach (bt::TorrentInterface* tc, downloads)
+        for (bt::TorrentInterface* tc : qAsConst(downloads))
         {
             if (IsStalled(tc, now, min_stall_time))
             {
@@ -799,7 +803,7 @@ namespace kt
         if (stalled.count() == 0 || stalled.count() == downloads.count() || !can_decrease)
             return;
 
-        foreach (bt::TorrentInterface* tc, stalled)
+        for (bt::TorrentInterface* tc : qAsConst(stalled))
             Out(SYS_GEN | LOG_NOTICE) << "The torrent " << tc->getStats().torrent_name << " has stalled longer than " << min_stall_time << " minutes, decreasing its priority" << endl;
 
         downloads.clear();
@@ -807,7 +811,7 @@ namespace kt
         downloads += stalled;
         // redo priorities and then order the queue
         int prio = downloads.count();
-        foreach (bt::TorrentInterface* tc, downloads)
+        for (bt::TorrentInterface* tc : qAsConst(downloads))
         {
             tc->setPriority(prio--);
         }
@@ -824,7 +828,7 @@ namespace kt
             // running torrents, that they need to reannounce and kill stale peers
             if (network_down_time.isValid() && network_down_time.secsTo(QDateTime::currentDateTime()) > 120)
             {
-                foreach (bt::TorrentInterface* tc, downloads)
+                for (bt::TorrentInterface* tc : qAsConst(downloads))
                 {
                     if (tc->getStats().running)
                         tc->networkUp();
@@ -844,7 +848,7 @@ namespace kt
     {
         int prio = downloads.count();
         // make sure everybody has an unique priority
-        foreach (bt::TorrentInterface* tc, downloads)
+        for (bt::TorrentInterface* tc : qAsConst(downloads))
         {
             tc->setPriority(prio--);
         }
@@ -858,7 +862,7 @@ namespace kt
         if (suspended_state)
         {
             QStringList info_hash_list = g.readEntry("suspended_torrents", QStringList());
-            foreach (bt::TorrentInterface* t, downloads)
+            for (bt::TorrentInterface* t : qAsConst(downloads))
             {
                 if (info_hash_list.contains(t->getInfoHash().toString()))
                     suspended_torrents.insert(t);
@@ -874,7 +878,7 @@ namespace kt
         if (suspended_state)
         {
             QStringList info_hash_list;
-            foreach (bt::TorrentInterface* t, suspended_torrents)
+            for (bt::TorrentInterface* t : qAsConst(suspended_torrents))
             {
                 info_hash_list << t->getInfoHash().toString();
             }
@@ -896,7 +900,7 @@ namespace kt
         else
             files.insert(tc->getStats().output_path);
 
-        foreach (bt::TorrentInterface* t, downloads)
+        for (bt::TorrentInterface* t : qAsConst(downloads))
         {
             if (t == tc)
                 continue;
@@ -933,7 +937,7 @@ namespace kt
 
     void QueuePtrList::sort()
     {
-        qSort(begin(), end(), QueuePtrList::biggerThan);
+        std::sort(begin(), end(), QueuePtrList::biggerThan);
     }
 
     bool QueuePtrList::biggerThan(bt::TorrentInterface* tc1, bt::TorrentInterface* tc2)
