@@ -18,12 +18,15 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include "downloadorderdialog.h"
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <interfaces/torrentinterface.h>
+#include <KConfig>
+#include <KConfigGroup>
+
 #include <QMenu>
+
+#include <interfaces/torrentinterface.h>
 #include "downloadordermanager.h"
 #include "downloadorderplugin.h"
 #include "downloadordermodel.h"
@@ -35,9 +38,9 @@ namespace kt
         : QDialog(parent), tor(tor), plugin(plugin)
     {
         setupUi(this);
-        connect(buttonBox,SIGNAL(accepted()),this,SLOT(accept()));
-        connect(buttonBox,SIGNAL(rejected()),this,SLOT(reject()));
-        connect(this, SIGNAL(accepted()), this, SLOT(commitDownloadOrder()));
+        connect(buttonBox, &QDialogButtonBox::accepted, this, &DownloadOrderDialog::accept);
+        connect(buttonBox, &QDialogButtonBox::rejected, this, &DownloadOrderDialog::reject);
+        connect(this, &DownloadOrderDialog::accepted, this, &DownloadOrderDialog::commitDownloadOrder);
         setWindowTitle(i18n("File Download Order"));
         m_top_label->setText(i18n("File download order for <b>%1</b>:", tor->getDisplayName()));
 
@@ -50,14 +53,14 @@ namespace kt
         m_move_bottom->setEnabled(false);
         m_search_files->setEnabled(false);
 
-        m_move_up->setIcon(QIcon::fromTheme("go-up"));
-        connect(m_move_up, SIGNAL(clicked()), this, SLOT(moveUp()));
-        m_move_down->setIcon(QIcon::fromTheme("go-down"));
-        connect(m_move_down, SIGNAL(clicked()), this, SLOT(moveDown()));
-        m_move_top->setIcon(QIcon::fromTheme("go-top"));
-        connect(m_move_top, SIGNAL(clicked()), this, SLOT(moveTop()));
-        m_move_bottom->setIcon(QIcon::fromTheme("go-bottom"));
-        connect(m_move_bottom, SIGNAL(clicked()), this, SLOT(moveBottom()));
+        m_move_up->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
+        connect(m_move_up, &QPushButton::clicked, this, &DownloadOrderDialog::moveUp);
+        m_move_down->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
+        connect(m_move_down, &QPushButton::clicked, this, &DownloadOrderDialog::moveDown);
+        m_move_top->setIcon(QIcon::fromTheme(QStringLiteral("go-top")));
+        connect(m_move_top, &QPushButton::clicked, this, &DownloadOrderDialog::moveTop);
+        m_move_bottom->setIcon(QIcon::fromTheme(QStringLiteral("go-bottom")));
+        connect(m_move_bottom, &QPushButton::clicked, this, &DownloadOrderDialog::moveBottom);
 
         m_order->setSelectionMode(QAbstractItemView::ContiguousSelection);
         m_order->setDragEnabled(true);
@@ -75,8 +78,8 @@ namespace kt
 
         connect(m_order->selectionModel(), SIGNAL(selectionChanged(QItemSelection, QItemSelection)),
                 this, SLOT(itemSelectionChanged(QItemSelection, QItemSelection)));
-        connect(m_custom_order_enabled, SIGNAL(toggled(bool)), this, SLOT(customOrderEnableToggled(bool)));
-        connect(m_search_files, SIGNAL(textChanged(QString)), this, SLOT(search(QString)));
+        connect(m_custom_order_enabled, &QCheckBox::toggled, this, &DownloadOrderDialog::customOrderEnableToggled);
+        connect(m_search_files, &QLineEdit::textChanged, this, &DownloadOrderDialog::search);
 
         QMenu* sort_by_menu = new QMenu(m_sort_by);
         sort_by_menu->addAction(i18n("Name"), model, SLOT(sortByName()));
@@ -101,8 +104,7 @@ namespace kt
             if (!dom)
             {
                 dom = plugin->createManager(tor);
-                connect(tor, SIGNAL(chunkDownloaded(bt::TorrentInterface*, bt::Uint32)),
-                        dom, SLOT(chunkDownloaded(bt::TorrentInterface*, bt::Uint32)));
+                connect(tor, &bt::TorrentInterface::chunkDownloaded, dom, &DownloadOrderManager::chunkDownloaded);
             }
 
             dom->setDownloadOrder(model->downloadOrder());
