@@ -18,10 +18,15 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include "peerviewmodel.h"
+
 #include <QIcon>
 #include <QLocale>
-#include <klocalizedstring.h>
+#include <QStandardPaths>
+
+#include <KLocalizedString>
+
 #include <interfaces/torrentinterface.h>
 #include <util/functions.h>
 #include "flagdb.h"
@@ -44,7 +49,12 @@ namespace kt
             yes = QIcon::fromTheme(QStringLiteral("dialog-ok"));
             no = QIcon::fromTheme(QStringLiteral("dialog-cancel"));
             icons_loaded = true;
-            flagDB.addFlagSource(QStringLiteral("/usr/share/locale/l10n/%1/flag.png")); //part of kde-runtime-data package
+
+            QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                                  QStringLiteral("kf5/locale/countries"),
+                                                  QStandardPaths::LocateDirectory);
+            if (!path.isEmpty())
+                flagDB.addFlagSource(path + QStringLiteral("/%1/flag.png"));
         }
 
         if (geo_ip)
@@ -160,7 +170,7 @@ namespace kt
     /////////////////////////////////////////////////////////////
 
     PeerViewModel::PeerViewModel(QObject* parent)
-        : QAbstractTableModel(parent), geo_ip(0)
+        : QAbstractTableModel(parent), geo_ip(nullptr)
     {
         geo_ip = new GeoIPManager(this);
     }
@@ -191,9 +201,10 @@ namespace kt
 
     void PeerViewModel::clear()
     {
+        beginResetModel();
         qDeleteAll(items);
         items.clear();
-        reset();
+        endResetModel();
     }
 
     void PeerViewModel::update()
@@ -333,7 +344,7 @@ namespace kt
     bt::PeerInterface* PeerViewModel::indexToPeer(const QModelIndex& index)
     {
         if (!index.isValid() || index.row() >= items.count())
-            return 0;
+            return nullptr;
         else
             return ((Item*)index.internalPointer())->peer;
     }
