@@ -18,12 +18,14 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #ifndef KTTRACKERMODEL_H
 #define KTTRACKERMODEL_H
 
+#include <QAbstractTableModel>
 #include <QList>
 #include <QUrl>
-#include <QAbstractTableModel>
+
 #include <interfaces/trackerinterface.h>
 
 namespace bt
@@ -42,20 +44,20 @@ namespace kt
         Q_OBJECT
     public:
         TrackerModel(QObject* parent);
-        virtual ~TrackerModel();
+        ~TrackerModel();
 
         void changeTC(bt::TorrentInterface* tc);
         void update();
 
-        virtual int rowCount(const QModelIndex& parent) const;
-        virtual int columnCount(const QModelIndex& parent) const;
-        virtual QVariant data(const QModelIndex& index, int role) const;
-        virtual bool setData(const QModelIndex& index, const QVariant& value, int role);
-        virtual QVariant headerData(int section, Qt::Orientation orientation, int role) const;
-        virtual bool insertRows(int row, int count, const QModelIndex& parent);
-        virtual bool removeRows(int row, int count, const QModelIndex& parent);
-        virtual Qt::ItemFlags flags(const QModelIndex& index) const;
-        virtual QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const;
+        int rowCount(const QModelIndex& parent) const override;
+        int columnCount(const QModelIndex& parent) const override;
+        QVariant data(const QModelIndex& index, int role) const override;
+        bool setData(const QModelIndex& index, const QVariant& value, int role) override;
+        QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+        bool insertRows(int row, int count, const QModelIndex& parent) override;
+        bool removeRows(int row, int count, const QModelIndex& parent) override;
+        Qt::ItemFlags flags(const QModelIndex& index) const override;
+        QModelIndex index(int row, int column, const QModelIndex& parent = QModelIndex()) const override;
 
         /// Get a tracker url given a model index
         QUrl trackerUrl(const QModelIndex& idx);
