@@ -18,11 +18,13 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #ifndef KTWEBSEEDSMODEL_H
 #define KTWEBSEEDSMODEL_H
 
-#include <QVector>
 #include <QAbstractTableModel>
+#include <QVector>
+
 #include <util/constants.h>
 #include <interfaces/torrentinterface.h>
 
@@ -38,7 +40,7 @@ namespace kt
 
     public:
         WebSeedsModel(QObject* parent);
-        virtual ~WebSeedsModel();
+        ~WebSeedsModel();
 
 
         /**
@@ -52,12 +54,12 @@ namespace kt
          */
         bool update();
 
-        virtual int rowCount(const QModelIndex& parent = QModelIndex()) const;
-        virtual int columnCount(const QModelIndex& parent = QModelIndex()) const;
-        virtual QVariant headerData(int section, Qt::Orientation orientation, int role) const;
-        virtual QVariant data(const QModelIndex& index, int role) const;
-        virtual Qt::ItemFlags flags(const QModelIndex& index) const;
-        virtual bool setData(const QModelIndex& index, const QVariant& value, int role);
+        int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+        int columnCount(const QModelIndex& parent = QModelIndex()) const override;
+        QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+        QVariant data(const QModelIndex& index, int role) const override;
+        Qt::ItemFlags flags(const QModelIndex& index) const override;
+        bool setData(const QModelIndex& index, const QVariant& value, int role) override;
 
     private:
         struct Item
