@@ -17,9 +17,13 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include <QDockWidget>
-#include <kpluginfactory.h>
-#include <klocalizedstring.h>
+
+#include <KPluginFactory>
+#include <KLocalizedString>
+#include <KMainWindow>
+
 #include <util/log.h>
 #include <torrent/globals.h>
 #include <interfaces/guiinterface.h>
@@ -30,7 +34,6 @@
 #include "logprefpage.h"
 #include "logflags.h"
 #include "logviewerpluginsettings.h"
-#include <kmainwindow.h>
 
 
 using namespace bt;
@@ -39,14 +42,11 @@ K_PLUGIN_FACTORY_WITH_JSON(ktorrent_logviewer, "ktorrent_logviewer.json", regist
 
 namespace kt
 {
-
-
-
     LogViewerPlugin::LogViewerPlugin(QObject* parent, const QVariantList&) : Plugin(parent)
-        , lv(0)
-        , pref(0)
-        , flags(0)
-        , dock(0)
+        , lv(nullptr)
+        , pref(nullptr)
+        , flags(nullptr)
+        , dock(nullptr)
         , pos(SEPARATE_ACTIVITY)
     {
     }
@@ -61,7 +61,7 @@ namespace kt
         connect(getCore(), SIGNAL(settingsChanged()), this, SLOT(applySettings()));
         flags = new LogFlags();
         lv = new LogViewer(flags);
-        pref = new LogPrefPage(flags, 0);
+        pref = new LogPrefPage(flags, nullptr);
 
         pos = (LogViewerPosition)LogViewerPluginSettings::logWidgetPosition();
         addLogViewerToGUI();
@@ -78,11 +78,11 @@ namespace kt
         removeLogViewerFromGUI();
         RemoveLogMonitor(lv);
         delete lv;
-        lv = 0;
+        lv = nullptr;
         delete pref;
-        pref = 0;
+        pref = nullptr;
         delete flags;
-        flags = 0;
+        flags = nullptr;
     }
 
     void LogViewerPlugin::applySettings()
@@ -110,7 +110,7 @@ namespace kt
             KMainWindow* mwnd = getGUI()->getMainWindow();
             dock = new QDockWidget(mwnd);
             dock->setWidget(lv);
-            dock->setObjectName("LogViewerDockWidget");
+            dock->setObjectName(QStringLiteral("LogViewerDockWidget"));
             mwnd->addDockWidget(Qt::BottomDockWidgetArea, dock);
             break;
         }
@@ -134,10 +134,10 @@ namespace kt
         {
             KMainWindow* mwnd = getGUI()->getMainWindow();
             mwnd->removeDockWidget(dock);
-            dock->setWidget(0);
-            lv->setParent(0);
+            dock->setWidget(nullptr);
+            lv->setParent(nullptr);
             delete dock;
-            dock = 0;
+            dock = nullptr;
             break;
         }
         }
@@ -151,7 +151,7 @@ namespace kt
 
     bool LogViewerPlugin::versionCheck(const QString& version) const
     {
-        return version == KT_VERSION_MACRO;
+        return version == QStringLiteral(KT_VERSION_MACRO);
     }
 
 }
