@@ -18,15 +18,17 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-
 #include "scanthread.h"
+
+#include <QCoreApplication>
 #include <QDir>
 #include <QEvent>
-#include <QCoreApplication>
-#include <klocalizedstring.h>
-#include <util/fileops.h>
 #include <QTimer>
 
+#include <KLocalizedString>
+
+#include <util/fileops.h>
+
 
 namespace kt
 {
@@ -39,20 +41,20 @@ namespace kt
         UpdateFolderEvent() : QEvent((QEvent::Type)UPDATE_FOLDER_EVENT)
         {}
 
-        virtual ~UpdateFolderEvent()
+        ~UpdateFolderEvent()
         {}
     };
 
     class RecursiveScanEvent : public QEvent
     {
     public:
-        RecursiveScanEvent(const KUrl& url) : QEvent((QEvent::Type)RECURSIVE_SCAN_EVENT), url(url)
+        RecursiveScanEvent(const QUrl& url) : QEvent((QEvent::Type)RECURSIVE_SCAN_EVENT), url(url)
         {}
 
-        virtual ~RecursiveScanEvent()
+        ~RecursiveScanEvent()
         {}
 
-        KUrl url;
+        QUrl url;
     };
 
     ScanThread::ScanThread()
@@ -75,7 +77,7 @@ namespace kt
     }
 
 
-    void ScanThread::addDirectory(const KUrl& url, bool recursive)
+    void ScanThread::addDirectory(const QUrl& url, bool recursive)
     {
         scan(url, recursive);
     }
@@ -139,7 +141,7 @@ namespace kt
             if (QDir(folder).exists())
             {
                 // only add folder when it exists
-                ScanFolder* sf = new ScanFolder(this, folder, recursive);
+                ScanFolder* sf = new ScanFolder(this, QUrl::fromLocalFile(folder), recursive);
                 scan_folders.insert(folder, sf);
             }
         }
@@ -160,11 +162,11 @@ namespace kt
 
     bool ScanThread::alreadyLoaded(const QDir& d, const QString& torrent)
     {
-        return d.exists('.' + torrent);
+        return d.exists(QLatin1Char('.') + torrent);
     }
 
 
-    void ScanThread::scan(const KUrl& dir, bool recursive)
+    void ScanThread::scan(const QUrl& dir, bool recursive)
     {
         if (stop_requested)
             return;
@@ -174,11 +176,11 @@ namespace kt
         QDir d(dir.toLocalFile());
         QStringList files = d.entryList(filters, QDir::Readable | QDir::Files);
 
-        KUrl::List torrents;
+        QList<QUrl> torrents;
         foreach (const QString& tor, files)
         {
             if (!alreadyLoaded(d, tor))
-                torrents.append(d.absoluteFilePath(tor));
+                torrents.append(QUrl::fromLocalFile(d.absoluteFilePath(tor)));
         }
 
         found(torrents);
@@ -193,9 +195,9 @@ namespace kt
             QStringList dirs = d.entryList(QDir::Readable | QDir::Dirs);
             foreach (const QString& subdir, dirs)
             {
-                if (subdir != QLatin1String(".") && subdir != QLatin1String("..") && subdir != loaded_localized)
+                if (subdir != QStringLiteral(".") && subdir != QStringLiteral("..") && subdir != loaded_localized)
                 {
-                    QCoreApplication::postEvent(this, new RecursiveScanEvent(d.absoluteFilePath(subdir)));
+                    QCoreApplication::postEvent(this, new RecursiveScanEvent(QUrl::fromLocalFile(d.absoluteFilePath(subdir))));
                 }
             }
         }
