@@ -18,6 +18,7 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #ifndef KTSCRIPTINGPLUGIN_H
 #define KTSCRIPTINGPLUGIN_H
 
@@ -38,12 +39,12 @@ namespace kt
     {
         Q_OBJECT
     public:
-        ScriptingPlugin(QObject* parent, const QStringList& args);
-        virtual ~ScriptingPlugin();
+        ScriptingPlugin(QObject* parent, const QVariantList& args);
+        ~ScriptingPlugin();
 
-        virtual void load();
-        virtual void unload();
-        virtual bool versionCheck(const QString& version) const;
+        void load() override;
+        void unload() override;
+        bool versionCheck(const QString& version) const override;
 
     private:
         void scriptDownloadFinished(KJob* job);
