@@ -17,16 +17,21 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
-#include <QFile>
-#include <QTextStream>
-#include <QStringList>
+
 #include <QDir>
-#include <klocalizedstring.h>
-#include <kio/copyjob.h>
+#include <QFile>
+#include <QStandardPaths>
+#include <QStringList>
+#include <QTextStream>
+#include <QUrlQuery>
+
+#include <KIO/CopyJob>
+#include <KLocalizedString>
+
 #include <util/log.h>
 #include <util/error.h>
 #include <util/fileops.h>
-#include <QStandardPaths>
+#include <interfaces/functions.h>
 #include "searchenginelist.h"
 #include "opensearchdownloadjob.h"
 
@@ -34,17 +39,14 @@ using namespace bt;
 
 namespace kt
 {
-    QString DataDir();
 
-    SearchEngineList::SearchEngineList(const QString& data_dir) : data_dir(data_dir)
+    SearchEngineList::SearchEngineList(ProxyHelper *proxy, const QString& data_dir) : m_proxy(proxy), data_dir(data_dir)
     {
-        default_opensearch_urls << QUrl(QLatin1String("http://www.torrentz.com")) << QUrl(QLatin1String("http://isohunt.com"));
-        default_urls << QUrl(QLatin1String("http://www.ktorrents.com"))
-                     << QUrl(QLatin1String("http://www.bittorrent.com"))
-                     << QUrl(QLatin1String("http://www.mininova.org"))
-                     << QUrl(QLatin1String("http://thepiratebay.org"))
-                     << QUrl(QLatin1String("http://www.bitenova.org"))
-                     << QUrl(QLatin1String("http://btjunkie.org"));
+        // default_opensearch_urls << QUrl(QStringLiteral("https://torrentproject.com"));
+        default_urls << QUrl(QStringLiteral("http://btdig.com"))
+                     << QUrl(QStringLiteral("http://btdb.in"))
+                     << QUrl(QStringLiteral("https://torrentproject.se"))
+                     << QUrl(QStringLiteral("http://duckduckgo.com"));
     }
 
 
@@ -58,7 +60,7 @@ namespace kt
     {
         if (!bt::Exists(data_dir))
         {
-            if (bt::Exists(kt::DataDir() + QLatin1String("search_engines")))
+            if (bt::Exists(kt::DataDir() + QStringLiteral("search_engines")))
             {
                 try
                 {
@@ -80,18 +82,16 @@ namespace kt
         }
         else
         {
-            QStringList subdirs = QDir(data_dir).entryList(QDir::Dirs);
-            foreach (const QString& sd, subdirs)
+            QStringList subdirs = QDir(data_dir).entryList(QDir::Dirs | QDir::NoDotAndDotDot);
+            for (const QString& sd : qAsConst(subdirs))
             {
-                if (sd == QLatin1String("..") || sd == QLatin1String("."))
-                    continue;
 
                 // Load only if there is an opensearch.xml file and not a removed file
-                if (bt::Exists(data_dir + sd + QLatin1String("/opensearch.xml")) && !bt::Exists(data_dir + sd + QLatin1String("/removed")))
+                if (bt::Exists(data_dir + sd + QStringLiteral("/opensearch.xml")) && !bt::Exists(data_dir + sd + QStringLiteral("/removed")))
                 {
                     Out(SYS_SRC | LOG_DEBUG) << "Loading " << sd << endl;
-                    SearchEngine* se = new SearchEngine(data_dir + sd + '/');
-                    if (!se->load(data_dir + sd + QLatin1String("/opensearch.xml")))
+                    SearchEngine* se = new SearchEngine(data_dir + sd + QLatin1Char('/'));
+                    if (!se->load(data_dir + sd + QStringLiteral("/opensearch.xml")))
                         delete se;
                     else
                         engines.append(se);
@@ -105,7 +105,7 @@ namespace kt
 
     void SearchEngineList::convertSearchEnginesFile()
     {
-        QFile fptr(kt::DataDir() + QLatin1String("search_engines"));
+        QFile fptr(kt::DataDir() + QStringLiteral("search_engines"));
         if (!fptr.open(QIODevice::ReadOnly))
         {
             addDefaults();
@@ -118,24 +118,24 @@ namespace kt
         {
             QString line = in.readLine();
 
-            if (line.startsWith('#') || line.startsWith(' ') || line.isEmpty()) continue;
+            if (line.startsWith(QLatin1Char('#')) || line.startsWith(QLatin1Char(' ')) || line.isEmpty()) continue;
 
-            QStringList tokens = line.split(' ');
+            QStringList tokens = line.split(QLatin1Char(' '));
             QString name = tokens[0];
             name = name.replace(QLatin1String("%20"), QLatin1String(" "));
-            QUrl url = QUrl(tokens[1]);
+            QUrlQuery url = QUrlQuery(QUrl(tokens[1]));
 
             for (Uint32 i = 2; i < (Uint32)tokens.count(); ++i)
-                url.addQueryItem(tokens[i].section('=', 0, 0), tokens[i].section('=', 1, 1));
+                url.addQueryItem(tokens[i].section(QLatin1Char('='), 0, 0), tokens[i].section(QLatin1Char('='), 1, 1));
 
             try
             {
                 QString dir = data_dir + name;
-                if (!dir.endsWith('/'))
-                    dir += '/';
+                if (!dir.endsWith(QLatin1Char('/')))
+                    dir += QLatin1Char('/');
 
                 bt::MakeDir(dir);
-                addEngine(dir, url.toDisplayString().replace(QLatin1String("FOOBAR"), QLatin1String("{searchTerms}")));
+                addEngine(dir, url.toString().replace(QLatin1String("FOOBAR"), QLatin1String("{searchTerms}")));
             }
             catch (bt::Error& err)
             {
@@ -165,19 +165,22 @@ namespace kt
     void SearchEngineList::openSearchDownloadJobFinished(KJob* j)
     {
         OpenSearchDownloadJob* osdj = (OpenSearchDownloadJob*)j;
-        if (osdj->error())
-            bt::Delete(osdj->directory(), true);
-
-        SearchEngine* se = new SearchEngine(osdj->directory());
-        if (!se->load(osdj->directory() + QLatin1String("opensearch.xml")))
+        if (!osdj->error())
         {
-            delete se;
+            SearchEngine* se = new SearchEngine(osdj->directory());
+            if (!se->load(osdj->directory() + QStringLiteral("opensearch.xml")))
+            {
+                delete se;
+                bt::Delete(osdj->directory(), true);
+            }
+            else {
+                engines.append(se);
+                insertRow(engines.count() - 1);
+            }
+        }
+        else {
             bt::Delete(osdj->directory(), true);
         }
-        else
-            engines.append(se);
-
-        insertRow(engines.count() - 1);
     }
 
     void SearchEngineList::addEngine(OpenSearchDownloadJob* j)
@@ -187,33 +190,33 @@ namespace kt
 
     void SearchEngineList::addEngine(const QString& dir, const QString& url)
     {
-        QFile fptr(dir + QLatin1String("opensearch.xml"));
+        QFile fptr(dir + QStringLiteral("opensearch.xml"));
         if (!fptr.open(QIODevice::WriteOnly))
-            throw bt::Error(i18n("Cannot open %1: %2", dir + QLatin1String("opensearch.xml"), fptr.errorString()));
+            throw bt::Error(i18n("Cannot open %1: %2", dir + QStringLiteral("opensearch.xml"), fptr.errorString()));
 
         QUrl kurl(url);
         QTextStream out(&fptr);
-        QString xml_template = QLatin1String("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
+        QString xml_template = QStringLiteral("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
                                "<OpenSearchDescription xmlns=\"http://a9.com/-/spec/opensearch/1.1/\">\n"
                                "<ShortName>%1</ShortName>\n"
                                "<Url type=\"text/html\" template=\"%2\" />\n"
                                "<Image>%3/favicon.ico</Image>\n"
                                "</OpenSearchDescription>\n");
 
-        QString base = kurl.scheme() + QLatin1String("://") + kurl.host();
+        QString base = kurl.scheme() + QStringLiteral("://") + kurl.host();
         if (kurl.port() > 0)
             base += QString::fromLatin1(":%1").arg(kurl.port());
 
         QString tmp = url;
-        tmp = tmp.replace('&', QLatin1String("&amp;"));
+        tmp = tmp.replace(QLatin1Char('&'), QLatin1String("&amp;"));
         out << xml_template.arg(kurl.host()).arg(tmp).arg(base) << endl;
 
         SearchEngine* se = new SearchEngine(dir);
 
-        if (!se->load(dir + QLatin1String("opensearch.xml")))
+        if (!se->load(dir + QStringLiteral("opensearch.xml")))
         {
             delete se;
-            throw bt::Error(i18n("Failed to parse %1", dir + QLatin1String("opensearch.xml")));
+            throw bt::Error(i18n("Failed to parse %1", dir + QStringLiteral("opensearch.xml")));
         }
 
         engines.append(se);
@@ -223,27 +226,28 @@ namespace kt
     void SearchEngineList::removeEngines(const QModelIndexList& sel)
     {
         QList<SearchEngine*> to_remove;
-        foreach (const QModelIndex& idx, sel)
+        for (const QModelIndex& idx : sel)
         {
             if (idx.isValid() && idx.row() >= 0 && idx.row() < engines.count())
                 to_remove.append(engines.at(idx.row()));
         }
 
-        foreach (SearchEngine* se, to_remove)
+        beginResetModel();
+        for (SearchEngine* se : qAsConst(to_remove))
         {
-            bt::Touch(se->engineDir() + QLatin1String("removed"));
+            bt::Touch(se->engineDir() + QStringLiteral("removed"));
             engines.removeAll(se);
             delete se;
         }
-
-        reset();
+        endResetModel();
     }
 
     void SearchEngineList::removeAllEngines()
     {
+        beginResetModel();
         removeRows(0, engines.count(), QModelIndex());
         engines.clear();
-        reset();
+        endResetModel();
     }
 
     void SearchEngineList::addDefaults()
@@ -259,14 +263,15 @@ namespace kt
             return;
         }
 
-        foreach (const QUrl &u, default_opensearch_urls)
+        beginResetModel();
+        for (const QUrl &u : qAsConst(default_opensearch_urls))
         {
             Out(SYS_SRC | LOG_DEBUG) << "Setting up default engine " << u.toDisplayString() << endl;
-            QString dir = data_dir + u.host() + '/';
+            QString dir = data_dir + u.host() + QLatin1Char('/');
             if (!bt::Exists(dir))
             {
-                OpenSearchDownloadJob* j = new OpenSearchDownloadJob(u, dir);
-                connect(j, SIGNAL(result(KJob*)), this, SLOT(openSearchDownloadJobFinished(KJob*)));
+                OpenSearchDownloadJob* j = new OpenSearchDownloadJob(u, dir, m_proxy);
+                connect(j, &OpenSearchDownloadJob::result, this, &SearchEngineList::openSearchDownloadJobFinished);
                 j->start();
             }
             else
@@ -277,7 +282,7 @@ namespace kt
 
         // also add the engines which don't have an opensearch description
         loadDefault(true);
-        reset();
+        endResetModel();
     }
 
     void SearchEngineList::loadEngine(const QString& global_dir, const QString& user_dir, bool load_removed)
@@ -288,19 +293,19 @@ namespace kt
             bt::MakeDir(user_dir);
         }
 
-        if (bt::Exists(user_dir + QLatin1String("removed")))
+        if (bt::Exists(user_dir + QStringLiteral("removed")))
         {
             // if the removed file is there don't load, if we are not allowed
             if (!load_removed)
                 return;
             else
-                bt::Delete(user_dir + QLatin1String("removed"));
+                bt::Delete(user_dir + QStringLiteral("removed"));
         }
 
         if (!alreadyLoaded(user_dir))
         {
             SearchEngine* se = new SearchEngine(user_dir);
-            if (!se->load(global_dir + QLatin1String("opensearch.xml")))
+            if (!se->load(global_dir + QStringLiteral("opensearch.xml")))
                 delete se;
             else
                 engines.append(se);
@@ -310,23 +315,25 @@ namespace kt
 
     void SearchEngineList::loadDefault(bool removed_to)
     {
-        QStringList dir_list = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QLatin1String("ktorrent/opensearch"));
-        foreach (const QString& dir, dir_list)
-        {
-            QStringList subdirs = QDir(dir).entryList(QDir::Dirs);
-            foreach (const QString& sd, subdirs)
-            {
-                if (sd == QLatin1String("..") || sd == QLatin1String("."))
-                    continue;
+        QStringList dir_list = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("ktorrent/opensearch"), QStandardPaths::LocateDirectory);
+        if (dir_list.isEmpty())
+            dir_list = QStandardPaths::locateAll(QStandardPaths::DataLocation, QStringLiteral("ktorrent/opensearch"), QStandardPaths::LocateDirectory);
+        if (dir_list.isEmpty())
+            dir_list = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("ktorrent/opensearch"), QStandardPaths::LocateDirectory);
 
-                loadEngine(dir + sd + '/', data_dir + sd + '/', removed_to);
+        for (const QString& dir : qAsConst(dir_list))
+        {
+            const QStringList subdirs = QDir(dir).entryList(QDir::Dirs | QDir::NoDotAndDotDot);
+            for (const QString& sd : subdirs)
+            {
+                loadEngine(QDir::cleanPath(dir) + QLatin1Char('/') + sd + QLatin1Char('/'), data_dir + sd + QLatin1Char('/'), removed_to);
             }
         }
     }
 
     bool SearchEngineList::alreadyLoaded(const QString& user_dir)
     {
-        foreach (const SearchEngine* se, engines)
+        for (const SearchEngine* se : qAsConst(engines))
         {
             if (se->engineDir() == user_dir)
                 return true;
