@@ -17,23 +17,25 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include "searchplugin.h"
 
 #include <QFile>
 #include <QMenu>
 
-#include <kpluginfactory.h>
-//#include <ksharedconfig.h>
+#include <KActionCollection>
+#include <KLocalizedString>
+#include <KPluginFactory>
+#include <KRun>
+#include <KSharedConfig>
+#include <KShell>
 
-#include <klocalizedstring.h>
-#include <kactioncollection.h>
-#include <krun.h>
-#include <kshell.h>
 #include <interfaces/guiinterface.h>
 #include <interfaces/coreinterface.h>
 #include <interfaces/functions.h>
 #include <util/log.h>
 #include <util/logsystemmanager.h>
+#include <dbus/dbus.h>
 #include "searchwidget.h"
 #include "searchprefpage.h"
 #include "searchtoolbar.h"
@@ -48,10 +50,10 @@ using namespace bt;
 namespace kt
 {
 
-    SearchPlugin::SearchPlugin(QObject* parent, const QVariantList& args) : Plugin(parent), engines(0)
+    SearchPlugin::SearchPlugin(QObject* parent, const QVariantList& args) : Plugin(parent), engines(nullptr)
     {
         Q_UNUSED(args);
-        pref = 0;
+        pref = nullptr;
     }
 
 
@@ -62,19 +64,20 @@ namespace kt
     void SearchPlugin::load()
     {
         LogSystemManager::instance().registerSystem(i18nc("plugin name", "Search"), SYS_SRC);
-        engines = new SearchEngineList(kt::DataDir() + "searchengines/");
+        proxy = new ProxyHelper((DBusSettings*) getCore()->getExternalInterface()->settings());
+        engines = new SearchEngineList(proxy, kt::DataDir() + QStringLiteral("searchengines/"));
         engines->loadEngines();
 
-        pref = new SearchPrefPage(this, engines, 0);
+        pref = new SearchPrefPage(this, engines, nullptr);
         getGUI()->addPrefPage(pref);
         connect(getCore(), SIGNAL(settingsChanged()), this, SLOT(preferencesUpdated()));
 
-        activity = new SearchActivity(this, 0);
+        activity = new SearchActivity(this, nullptr);
         getGUI()->addActivity(activity);
         activity->loadCurrentSearches();
         activity->loadState(KSharedConfig::openConfig());
 
-        connect(pref, SIGNAL(clearSearchHistory()), activity, SLOT(clearSearchHistory()));
+        connect(pref, &SearchPrefPage::clearSearchHistory, activity, &SearchActivity::clearSearchHistory);
     }
 
     void SearchPlugin::unload()
@@ -86,12 +89,14 @@ namespace kt
 
         getGUI()->removePrefPage(pref);
         delete pref;
-        pref = 0;
+        pref = nullptr;
         disconnect(getCore(), SIGNAL(settingsChanged()), this, SLOT(preferencesUpdated()));
         delete engines;
-        engines = 0;
+        engines = nullptr;
         delete activity;
-        activity = 0;
+        activity = nullptr;
+        delete proxy;
+        proxy = nullptr;
     }
 
     void SearchPlugin::search(const QString& text, int engine, bool external)
@@ -106,7 +111,7 @@ namespace kt
             if (SearchPluginSettings::useDefaultBrowser())
                 new KRun(url, QApplication::activeWindow());
             else
-                KRun::runCommand(SearchPluginSettings::customBrowser() + ' ' + KShell::quoteArg(url.toDisplayString()), 0);
+                KRun::runCommand(SearchPluginSettings::customBrowser() + QStringLiteral(" ") + KShell::quoteArg(url.toDisplayString()), nullptr);
         }
         else
         {
@@ -121,7 +126,7 @@ namespace kt
 
     bool SearchPlugin::versionCheck(const QString& version) const
     {
-        return version == KT_VERSION_MACRO;
+        return version == QStringLiteral(KT_VERSION_MACRO);
     }
 
 }
