@@ -17,6 +17,7 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #ifndef BTSEARCHWIDGET_H
 #define BTSEARCHWIDGET_H
 
@@ -30,11 +31,6 @@ class QNetworkReply;
 class QMenu;
 class KComboBox;
 
-namespace KParts
-{
-    class Part;
-}
-
 namespace kt
 {
     class SearchWidget;
@@ -51,7 +47,7 @@ namespace kt
         Q_OBJECT
     public:
         SearchWidget(SearchPlugin* sp);
-        virtual ~SearchWidget();
+        ~SearchWidget();
 
         QString getSearchText() const {return search_text->text();}
         QUrl getCurrentUrl() const;
@@ -82,9 +78,9 @@ namespace kt
         void titleChanged(const QString& text);
 
     private:
-        virtual QUrl searchUrl(const QString& search_text);
-        virtual QWebView* newTab();
-        virtual void magnetUrl(const QUrl& magnet_url);
+        QUrl searchUrl(const QString& search_text) override;
+        QWebView* newTab() override;
+        void magnetUrl(const QUrl& magnet_url) override;
 
     private:
         WebView* webview;
