@@ -18,11 +18,12 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #ifndef KTLINKDOWNLOADER_H
 #define KTLINKDOWNLOADER_H
 
 #include <QObject>
-#include <kurl.h>
+#include <QUrl>
 
 class KJob;
 
@@ -39,13 +40,12 @@ namespace kt
     {
         Q_OBJECT
     public:
-        LinkDownloader(const KUrl& url, CoreInterface* core, bool verbose, const QString& group, const QString& location, const QString& move_on_completion);
-        virtual ~LinkDownloader();
+        LinkDownloader(const QUrl& url, CoreInterface* core, bool verbose, const QString& group, const QString& location, const QString& move_on_completion);
+        ~LinkDownloader();
 
         /// Start the download proces
         void start();
 
-    private slots:
         void downloadFinished(KJob* j);
         void torrentDownloadFinished(KJob* j);
 
@@ -55,15 +55,15 @@ namespace kt
         void tryNextLink();
         void tryTorrentLinks();
 
-    signals:
+    Q_SIGNALS:
         void finished(bool ok);
 
     private:
-        KUrl url;
+        QUrl url;
         CoreInterface* core;
         bool verbose;
-        KUrl link_url;
-        KUrl::List links;
+        QUrl link_url;
+        QList<QUrl> links;
         QString group;
         QString location;
         QString move_on_completion;
