@@ -17,11 +17,14 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include <QHBoxLayout>
+#include <QInputDialog>
 #include <QToolButton>
-#include <kmessagebox.h>
-#include <kinputdialog.h>
-#include <kmainwindow.h>
+
+#include <KMainWindow>
+#include <KMessageBox>
+
 #include <magnet/magnetlink.h>
 #include <interfaces/functions.h>
 #include <interfaces/guiinterface.h>
@@ -31,7 +34,7 @@
 #include <syndication/loader.h>
 #include "syndicationactivity.h"
 #include "feedwidget.h"
-#include "feed.h"
+#include "ktfeed.h"
 #include "feedlist.h"
 #include "feedlistview.h"
 #include "filter.h"
@@ -48,9 +51,9 @@
 namespace kt
 {
     SyndicationActivity::SyndicationActivity(SyndicationPlugin* sp, QWidget* parent)
-        : Activity(i18n("Syndication"), "application-rss+xml", 30, parent), sp(sp)
+        : Activity(i18n("Syndication"), QStringLiteral("application-rss+xml"), 30, parent), sp(sp)
     {
-        QString ddir = kt::DataDir() + "syndication/";
+        QString ddir = kt::DataDir() + QStringLiteral("syndication/");
         if (!bt::Exists(ddir))
             bt::MakeDir(ddir, true);
 
@@ -69,14 +72,14 @@ namespace kt
         splitter->setStretchFactor(0, 1);
         splitter->setStretchFactor(1, 3);
 
-        connect(tab->feedView(), SIGNAL(feedActivated(Feed*)), this, SLOT(showFeed(Feed*)));
-        connect(tab->feedView(), SIGNAL(enableRemove(bool)), sp->remove_feed, SLOT(setEnabled(bool)));
-        connect(tab->feedView(), SIGNAL(enableRemove(bool)), sp->manage_filters, SLOT(setEnabled(bool)));
-        connect(tab->filterView(), SIGNAL(filterActivated(Filter*)), this, SLOT(editFilter(Filter*)));
-        connect(tab->filterView(), SIGNAL(enableRemove(bool)), sp->remove_filter, SLOT(setEnabled(bool)));
-        connect(tab->filterView(), SIGNAL(enableEdit(bool)), sp->edit_filter, SLOT(setEnabled(bool)));
+        connect(tab->feedView(), &kt::FeedListView::feedActivated, this, &SyndicationActivity::showFeed);
+        connect(tab->feedView(), &kt::FeedListView::enableRemove, sp->remove_feed, &QAction::setEnabled);
+        connect(tab->feedView(), &kt::FeedListView::enableRemove, sp->manage_filters, &QAction::setEnabled);
+        connect(tab->filterView(), &kt::FilterListView::filterActivated, this, static_cast<void(SyndicationActivity::*)(Filter*)>(&SyndicationActivity::editFilter));
+        connect(tab->filterView(), &kt::FilterListView::enableRemove, sp->remove_filter, &QAction::setEnabled);
+        connect(tab->filterView(), &kt::FilterListView::enableEdit, sp->edit_filter, &QAction::setEnabled);
 
-        filter_list->loadFilters(kt::DataDir() + "syndication/filters");
+        filter_list->loadFilters(kt::DataDir() + QStringLiteral("syndication/filters"));
         feed_list->loadFeeds(filter_list, this);
         feed_list->importOldFeeds();
     }
@@ -115,23 +118,24 @@ namespace kt
     void SyndicationActivity::addFeed()
     {
         bool ok = false;
-        QString url = KInputDialog::getText(i18n("Enter the URL"), i18n("Please enter the URL of the RSS or Atom feed."),
-                                            QString(), &ok, sp->getGUI()->getMainWindow());
+        QString url = QInputDialog::getText(sp->getGUI()->getMainWindow(), i18n("Enter the URL"),
+                                            i18n("Please enter the URL of the RSS or Atom feed."),
+                                            QLineEdit::Normal, QString(), &ok);
         if (!ok || url.isEmpty())
             return;
 
         Syndication::Loader* loader = Syndication::Loader::create(this, SLOT(loadingComplete(Syndication::Loader*, Syndication::FeedPtr, Syndication::ErrorCode)));
-        QStringList sl = url.split(":COOKIE:");
+        QStringList sl = url.split(QStringLiteral(":COOKIE:"));
         if (sl.size() == 2)
         {
             FeedRetriever* retr = new FeedRetriever();
             retr->setAuthenticationCookie(sl.last());
-            loader->loadFrom(KUrl(sl.first()), retr);
+            loader->loadFrom(QUrl(sl.first()), retr);
             downloads.insert(loader, url);
         }
         else
         {
-            loader->loadFrom(KUrl(url));
+            loader->loadFrom(QUrl(url));
             downloads.insert(loader, url);
         }
     }
@@ -148,10 +152,9 @@ namespace kt
 
         try
         {
-            QString ddir = kt::DataDir() + "syndication/";
+            QString ddir = kt::DataDir() + QStringLiteral("syndication/");
             Feed* f = new Feed(downloads[loader], feed, Feed::newFeedDir(ddir));
-            connect(f, SIGNAL(downloadLink(const KUrl&, const QString&, const QString&, const QString&, bool)),
-                    this, SLOT(downloadLink(const KUrl&, const QString&, const QString&, const QString&, bool)));
+            connect(f, &Feed::downloadLink, this, &SyndicationActivity::downloadLink);
             f->save();
             feed_list->addFeed(f);
             feed_widget->setFeed(f);
@@ -186,20 +189,20 @@ namespace kt
     }
 
 
-    void SyndicationActivity::downloadLink(const KUrl& url,
+    void SyndicationActivity::downloadLink(const QUrl& url,
                                            const QString& group,
                                            const QString& location,
                                            const QString& move_on_completion,
                                            bool silently)
     {
-        if (url.protocol() == "magnet")
+        if (url.scheme() == QStringLiteral("magnet"))
         {
             MagnetLinkLoadOptions options;
             options.silently = silently;
             options.group = group;
             options.location = location;
             options.move_on_completion = move_on_completion;
-            sp->getCore()->load(bt::MagnetLink(url.prettyUrl()), options);
+            sp->getCore()->load(bt::MagnetLink(url), options);
         }
         else
         {
@@ -216,7 +219,7 @@ namespace kt
         if (dlg.exec() == QDialog::Accepted)
         {
             filter_list->addFilter(filter);
-            filter_list->saveFilters(kt::DataDir() + "syndication/filters");
+            filter_list->saveFilters(kt::DataDir() + QStringLiteral("syndication/filters"));
             return filter;
         }
         else
@@ -233,9 +236,9 @@ namespace kt
 
     void SyndicationActivity::removeFilter()
     {
-        QModelIndexList indexes = tab->filterView()->selectedFilters();
+        const QModelIndexList indexes = tab->filterView()->selectedFilters();
         QList<Filter*> to_remove;
-        foreach (const QModelIndex& idx, indexes)
+        for (const QModelIndex& idx : indexes)
         {
             Filter* f = filter_list->filterForIndex(idx);
             if (f)
@@ -249,7 +252,7 @@ namespace kt
             delete f;
         }
 
-        filter_list->saveFilters(kt::DataDir() + "syndication/filters");
+        filter_list->saveFilters(kt::DataDir() + QStringLiteral("syndication/filters"));
     }
 
     void SyndicationActivity::editFilter()
@@ -269,7 +272,7 @@ namespace kt
         if (dlg.exec() == QDialog::Accepted)
         {
             filter_list->filterEdited(f);
-            filter_list->saveFilters(kt::DataDir() + "syndication/filters");
+            filter_list->saveFilters(kt::DataDir() + QStringLiteral("syndication/filters"));
             feed_list->filterEdited(f);
         }
     }
