@@ -22,9 +22,9 @@
 #define SYNDICATIONACTIVITY_H
 
 #include <QSplitter>
-#include <ktabwidget.h>
+#include <Syndication/Loader>
+
 #include <interfaces/activity.h>
-#include <syndication/loader.h>
 
 namespace kt
 {
@@ -39,21 +39,20 @@ namespace kt
 
     class SyndicationActivity : public kt::Activity
     {
-        Q_OBJECT
+    Q_OBJECT
+
     public:
         SyndicationActivity(SyndicationPlugin* sp, QWidget* parent);
-        virtual ~SyndicationActivity();
+        ~SyndicationActivity();
 
         void loadState(KSharedConfigPtr cfg);
         void saveState(KSharedConfigPtr cfg);
         Filter* addNewFilter();
 
-    private slots:
         void addFeed();
         void removeFeed();
-        void loadingComplete(Syndication::Loader* loader, Syndication::FeedPtr feed, Syndication::ErrorCode status);
         void showFeed(Feed* f);
-        void downloadLink(const KUrl& url, const QString& group, const QString& location, const QString& move_on_completion, bool silently);
+        void downloadLink(const QUrl& url, const QString& group, const QString& location, const QString& move_on_completion, bool silently);
         void addFilter();
         void removeFilter();
         void editFilter();
@@ -61,6 +60,9 @@ namespace kt
         void manageFilters();
         void editFeedName();
 
+    public Q_SLOTS:
+        void loadingComplete(Syndication::Loader* loader, Syndication::FeedPtr feed, Syndication::ErrorCode status);
+
     private:
         FeedList* feed_list;
         FilterList* filter_list;
