@@ -17,21 +17,24 @@
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
-#include <time.h>
+
+#include <ctime>
+
+#include <QDateTime>
 #include <QDir>
+#include <QFileInfo>
+#include <QHostAddress>
 #include <QRegExp>
 #include <QSocketNotifier>
-#include <QFileInfo>
 #include <QStringList>
-#include <QHostAddress>
 #include <QTimer>
-#include <QDateTime>
-#include <kcodecs.h>
-#include <kapplication.h>
-#include <kgenericfactory.h>
-#include <kglobal.h>
-#include <kstandarddirs.h>
-#include <ktemporaryfile.h>
+
+#include <KApplication>
+#include <KCodecs>
+#include <KGenericFactory>
+#include <KGlobal>
+#include <KStandardDirs>
+#include <KTemporaryFile>
 #include <k3streamsocket.h>
 #include <k3resolver.h>
 
@@ -146,7 +149,7 @@ namespace kt
     void HttpServer::newConnection(int fd, const net::Address& addr)
     {
         HttpClientHandler* handler = new HttpClientHandler(this, fd);
-        connect(handler, SIGNAL(closed()), this, SLOT(slotConnectionClosed()));
+        connect(handler, &HttpClientHandler::closed, this, &HttpServer::slotConnectionClosed);
         Out(SYS_WEB | LOG_NOTICE) << "connection from " << addr.toString()  << endl;
         clients.append(handler);
     }
@@ -266,6 +269,8 @@ namespace kt
             return "image/" + ext;
         else if (ext == "jpg" || ext == "jpeg")
             return "image/jpeg";
+        else if (ext == "svg" || ext == "svgz")
+            return "image/svg+xml";
         else
             return QString::null;
     }
